# Jupyterlab Ukrainian (Ukraine) Language Pack

Ukrainian (Ukraine) language pack for the JupyterLab ecosystem.

## Install

### pip

```bash
pip install jupyterlab-language-pack-uk-UA
```

### conda

```bash
conda install -c conda-forge jupyterlab-language-pack-uk-UA
```

## Contributing

To contribute to this package please visit the [Crowdin site](https://crowdin.com/project/jupyterlab).
